Module :py:mod:`pyqt_fit.nonparam_regression`
=============================================

.. automodule:: pyqt_fit.nonparam_regression

.. autoclass:: NonParamRegression
   :members: copy, need_fit, fitted, kernel, kernel_type, bandwidth,
             covariance, bandwidth_function, covariance_function,
             lower, upper, xdata, ydata, method, fitted_method, N, dim,
             set_actual_bandwidth, fit, evaluate, __call__

